Rename SPARC V8 target to be the LLVM SPARC target.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@25985 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/Sparc/SparcTargetMachine.h b/lib/Target/Sparc/SparcTargetMachine.h
index 0977744..196ad75 100644
--- a/lib/Target/Sparc/SparcTargetMachine.h
+++ b/lib/Target/Sparc/SparcTargetMachine.h
@@ -1,4 +1,4 @@
//===-- SparcV8TargetMachine.h - Define TargetMachine for SparcV8 -*- C++ -*-=//
//
// The LLVM Compiler Infrastructure
//
@@ -7,33 +7,33 @@
//
//===----------------------------------------------------------------------===//
//
-// This file declares the SparcV8 specific subclass of TargetMachine.
+// This file declares the Sparc specific subclass of TargetMachine.
//
//===----------------------------------------------------------------------===//
-#ifndef SPARCV8TARGETMACHINE_H
-#define SPARCV8TARGETMACHINE_H
+#ifndef SPARCTARGETMACHINE_H
+#define SPARCTARGETMACHINE_H
#include "llvm/Target/TargetMachine.h"
#include "llvm/Target/TargetFrameInfo.h"
#include "llvm/PassManager.h"
-#include "SparcV8InstrInfo.h"
-#include "SparcV8Subtarget.h"
+#include "SparcInstrInfo.h"
+#include "SparcSubtarget.h"
namespace llvm {
class IntrinsicLowering;
class Module;
-class SparcV8TargetMachine : public TargetMachine {
- SparcV8Subtarget Subtarget;
- SparcV8InstrInfo InstrInfo;
+class SparcTargetMachine : public TargetMachine {
+ SparcSubtarget Subtarget;
+ SparcInstrInfo InstrInfo;
TargetFrameInfo FrameInfo;
public:
- SparcV8TargetMachine(const Module &M, IntrinsicLowering *IL,
- const std::string &FS);
+ SparcTargetMachine(const Module &M, IntrinsicLowering *IL,
+ const std::string &FS);
- virtual const SparcV8InstrInfo *getInstrInfo() const { return &InstrInfo; }
+ virtual const SparcInstrInfo *getInstrInfo() const { return &InstrInfo; }
virtual const TargetFrameInfo *getFrameInfo() const { return &FrameInfo; }
virtual const TargetSubtarget *getSubtargetImpl() const{ return &Subtarget; }
virtual const MRegisterInfo *getRegisterInfo() const {
@@ -1,4 +1,4 @@
-//===-- SparcV8TargetMachine.h - Define TargetMachine for SparcV8 -*- C++ -*-=//
+//===-- SparcTargetMachine.h - Define TargetMachine for Sparc ---*- C++ -*-===//
//
// The LLVM Compiler Infrastructure